This function is deprecated and no longer used in import_gtfs() or export_gtfs().
The dataset gtfs_reference now contains the standard specifications.
Value
A named list, in which each element represents the R equivalent of each GTFS table standard (based on the specifications of 2022-05-09).