get_gtfs_standards: Generate GTFS standards (deprecated)

View source: R/get_gtfs_standards.R

get_gtfs_standardsR Documentation

Generate GTFS standards (deprecated)

Description

This function is deprecated and no longer used in import_gtfs() or export_gtfs(). The dataset gtfs_reference now contains the standard specifications.

Usage

get_gtfs_standards()

Value

A named list, in which each element represents the R equivalent of each GTFS table standard (based on the specifications of 2022-05-09).

See Also

gtfs_reference


gtfsio documentation built on May 20, 2026, 9:07 a.m.