View source: R/get_gtfs_standards.R
| get_gtfs_standards | R Documentation |
This function is deprecated and no longer used in import_gtfs() or export_gtfs().
The dataset gtfs_reference now contains the standard specifications.
get_gtfs_standards()
A named list, in which each element represents the R equivalent of each GTFS table standard (based on the specifications of 2022-05-09).
gtfs_reference
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.