Reads a GTFS text file from the main .zip file.
read_files(file, fields, extra_spec, tmpdir, quiet, encoding)A data.table representing the desired text file according to
the standards for reading and writing GTFS feeds with R.
A string. The name of the file (with .txt or .geojson extension) to
be read.
A named list. Passed by the user to import_gtfs.
A named list. Passed by the user to
import_gtfs.
A string. The path to the temporary folder where GTFS text files were unzipped to.
Whether to hide log messages and progress bars (defaults to TRUE).
A string. Passed to fread, defaults
to "unknown". Other possible options are "UTF-8" and
"Latin-1". Please note that this is not used to re-encode the input,
but to enable handling encoded strings in their native encoding.
gtfs_reference